/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.mail;

import java.util.Properties;

import org.xwiki.component.annotation.Role;
import org.xwiki.stability.Unstable;

/**
 * Represents all XWiki configuration options for the Mail Sending feature.
 *
 * @version $Id: 90b6a4d31eb49434cf746d795dc08c9936074076 $
 * @since 6.1M2
 */
@Role
@Unstable
public interface MailSenderConfiguration
{
    /**
     * @return the SMTP server
     */
    String getHost();

    /**
     * @return the SMTP server port
     */
    int getPort();

    /**
     * @return the SMTP user name to authenticate to the SMTP server, if any
     */
    String getUsername();

    /**
     * @return the SMTP password to authenticate to the SMTP server, if any
     */
    String getPassword();

    /**
     * @return the email address sending the email
     */
    String getFromAddress();

    /**
     * @return the list of additional Java Mail properties (in addition to the host, port, username and from
     *         properties) to use when sending the mail (eg {@code mail.smtp.starttls.enable=true} if TLS should be
     *         used). See <a href="https://javamail.java.net/nonav/docs/api/com/sun/mail/smtp/package-summary.html">Java
     *         Mail Properties</a> for the full list of available properties.
     */
    Properties getAdditionalProperties();

    /**
     * @return the full list of Java Mail properties to use when sending the email (this includes the Java Mail
     *         properties for host ({@code mail.smtp.host}), port ({@code mail.smtp.port}),
     *         username ({@code mail.smtp.user}), from {@code mail.smtp.from}) + the all the additional properties
     *         from {@link #getAdditionalProperties()}
     */
    Properties getAllProperties();

    /**
     * @return if true then the SMTP server requires authentication
     */
    boolean usesAuthentication();
}
